@@ -69,11 +69,11 @@ sub dump {
     if (ref $enc) {
       eval { $text = $enc->decode($text); };
       if (!!$@) {
-        $self->dump("[dump] 字符串解码失败：$@");
+        warn("[dump] 字符串解码失败：$@");
       }
     }
     else {
-      $self->dump("[dump] 无法猜测编码: $enc");
+      warn("[dump] 无法猜测编码: $enc");
     }
 
     my $name     = $self->{name} // $self->now;
